==> ZenTaoPMS.biz7.7.php5.4_5.6.zip: zentaopms/extension/biz/feedback/lang/de.php <==
<?php
global $config;
$lang->feedback->common            = 'Feedback';
$lang->feedback->module            = 'Module';
$lang->feedback->moduleAB          = 'Module';
$lang->feedback->allModule         = 'All Module';
$lang->feedback->manageCate        = 'Manage Module';
$lang->feedback->index             = 'Feedback Home';
$lang->feedback->create            = 'Add Feedback';
$lang->feedback->edit              = 'Edit Feedback';
$lang->feedback->editOthers        = 'Edit Other Feedback';
$lang->feedback->createFaq         = 'Add FAQ';
$lang->feedback->faq               = 'FAQ';
$lang->feedback->nonRDBrowse       = 'Feedback Interface';
$lang->feedback->browse            = 'Feedback List';
$lang->feedback->list              = 'Feedback';
$lang->feedback->header            = 'Feedback';
$lang->feedback->view              = 'Feedback Detail';
$lang->feedback->review            = 'Review';
$lang->feedback->reviewAction      = 'Review Feedback';
$lang->feedback->adminView         = 'Developer Interface';
$lang->feedback->admin             = 'Developer Feedback List';
$lang->feedback->close             = 'Close';
$lang->feedback->closeAction       = 'Close Feedback';
$lang->feedback->feelLike          = ' like it!';
$lang->feedback->ask               = 'Doubt';
$lang->feedback->toStory           = 'To ' . $lang->SRCommon;
$lang->feedback->toUserStory       = 'To ' . $lang->URCommon;
$lang->feedback->toTask            = 'To Task';
$lang->feedback->toBug             = 'To Bug';
$lang->feedback->toTodo            = 'To Todo';
$lang->feedback->toTicket          = 'To Ticket';
$lang->feedback->story             = $lang->SRCommon;
$lang->feedback->userStory         = $lang->URCommon;
$lang->feedback->bug               = 'Bug';
$lang->feedback->todo              = 'Todo';
$lang->feedback->task              = 'Task';
$lang->feedback->ticket            = 'Ticket';
$lang->feedback->reply             = 'Reply';
$lang->feedback->replyAction       = 'Reply Feedback';
$lang->feedback->convert           = 'Convert';
$lang->feedback->assign            = 'AssignTo';
$lang->feedback->assignAction      = 'Assign Feedback';
$lang->feedback->export            = 'Export';
$lang->feedback->exportAction      = 'Export Feedback';
$lang->feedback->assignTo          = 'AssignTo';
$lang->feedback->mailto            = 'Mailto';
$lang->feedback->delete            = 'Delete Feedback';
$lang->feedback->mailNotify        = 'Email Notification';
$lang->feedback->search            = 'Search';
$lang->feedback->comment           = 'Comment';
$lang->feedback->products          = 'Privilege';
$lang->feedback->batchEdit         = 'Batch Edit';
$lang->feedback->batchClose        = 'Batch Close';
$lang->feedback->batchReview       = 'Batch Review';
$lang->feedback->batchAssignTo     = 'Batch Assign';
$lang->feedback->batchChangeModule = 'Batch Change Modules';
$lang->feedback->manageProduct     = 'Manage User Privilege';
$lang->feedback->consumed          = 'Total Cost';
$lang->feedback->noFeedback        = 'No feedback for the time being.';
$lang->feedback->import            = 'Import';
$lang->feedback->exportTemplate    = 'Export Template';
$lang->feedback->exportData        = 'Export Data';
$lang->feedback->pri               = 'Pri';
$lang->feedback->source            = 'Source company';
$lang->feedback->sourceInfo        = 'Feedback source';
$lang->feedback->internalContact   = 'Internal contact';
$lang->feedback->company           = 'Feedback company';
$lang->feedback->email             = 'Feedback email';

$lang->feedback->id             = 'ID';
$lang->feedback->product        = $lang->productCommon;
$lang->feedback->title          = 'Title';
$lang->feedback->storyTitle     = $lang->SRCommon;
$lang->feedback->type           = 'Type';
$lang->feedback->solution       = 'Treatment Plan';
$lang->feedback->desc           = 'Description';
$lang->feedback->status         = 'Status';
$lang->feedback->subStatus      = 'Sub Status';
$lang->feedback->openedBy       = 'AddedBy';
$lang->feedback->openedDate     = 'Added';
$lang->feedback->processedBy    = 'RepliedBy';
$lang->feedback->processedDate  = 'Replied';
$lang->feedback->reviewedBy     = 'ReviewedBy';
$lang->feedback->reviewedDate   = 'Reviewed';
$lang->feedback->reviewResult   = 'Reviewed Result';
$lang->feedback->reviewedByAB   = 'Reviewer';
$lang->feedback->reviewedDateAB = 'Date';
$lang->feedback->reviewResultAB = 'Result';
$lang->feedback->assignedTo     = 'AssignedTo';
$lang->feedback->assignedDate   = 'Assigned';
$lang->feedback->closedBy       = 'ClosedBy';
$lang->feedback->closedDate     = 'Closed';
$lang->feedback->closedReason   = 'Close Reason';
$lang->feedback->public         = 'Public';
$lang->feedback->publicAB       = 'Public';
$lang->feedback->notify         = 'Notification';
$lang->feedback->notifyEmail    = 'Notification Email';
$lang->feedback->feedbackBy     = 'Feedback';
$lang->feedback->likes          = 'Likes';
$lang->feedback->result         = 'Result';
$lang->feedback->files          = 'Files';
$lang->feedback->labelBasic     = 'Basic';
$lang->feedback->dept           = 'Department';
$lang->feedback->editedBy       = 'ModifiedBy';
$lang->feedback->editedDate     = 'Last Modified';
$lang->feedback->contactInfo    = 'Contact';
$lang->feedback->noAssigned     = 'Unassigned';
$lang->feedback->deptManager    = 'Dept Manager';
$lang->feedback->reviewOpinion  = 'Review Opinion';
$lang->feedback->deleted        = 'Deleted';
$lang->feedback->project        = 'Select project';
$lang->feedback->execution      = 'Select ' . $lang->execution->common;

$lang->feedback->lblBasic       = 'Basic Info';
$lang->feedback->lblTrace       = 'Traceability Diagram';
$lang->feedback->assigntome     = 'AssignedToMe';
$lang->feedback->allProduct     = 'All ' . $lang->productCommon;
$lang->feedback->nextStep       = 'Next';
$lang->feedback->selectProjects = 'Select Projects';
$lang->feedback->repeatFeedback = 'Repeat Feedback';

$lang->feedback->grantUser   = 'Authorized User';
$lang->feedback->noGrantUser = 'Unauthorized User';
$lang->feedback->hasPrivUser = 'Feedback users have privileges of all products by default. If any privilege is assigned, they will have the privileges of the related product.';

$lang->feedback->mergeModule    = 'Merge module';
$lang->feedback->mergeTip       = 'There are %d pieces of data to be merged this time, 50 pieces of data to be merged per page, and %d times to be merged.';
$lang->feedback->feedbackModule = 'Feedback module';
$lang->feedback->productModule  = 'Product module';
$lang->feedback->syncProduct    = 'Synchronize product modules';
$lang->feedback->syncProductTo  = 'Sync to product';
$lang->feedback->syncConfirm    = 'Whether to merge the existing module with the product module';
$lang->feedback->syncWarning    = 'After the product module is synchronized, it cannot be revoked. Please click Confirm carefully';

$lang->feedback->syncLeveList[1]  = 'One level module';
$lang->feedback->syncLeveList[2]  = 'Two level module';
$lang->feedback->syncLeveList[3]  = 'Three level module';
$lang->feedback->syncLeveList[4]  = 'Four level module';
$lang->feedback->syncLeveList[5]  = 'Five level module';

$lang->feedback->tabList['unclosed'] = 'Unclosed';
$lang->feedback->tabList['all']      = 'All';
$lang->feedback->tabList['public']   = 'Public';

$lang->feedback->typeList[''] = '';
$lang->feedback->typeList['story']       = 'Story';
$lang->feedback->typeList['task']        = 'Task';
$lang->feedback->typeList['bug']         = 'Bug';
$lang->feedback->typeList['todo']        = 'Todo';
$lang->feedback->typeList['advice']      = 'Advice';
if($this->config->systemMode == 'new')
{
    $lang->feedback->typeList['issue']       = 'Issue';
    $lang->feedback->typeList['risk']        = 'Risk';
    $lang->feedback->typeList['opportunity'] = 'Opportunity';
}

$lang->feedback->reviewResultList['']        = '';
$lang->feedback->reviewResultList['pass']    = 'Pass';
$lang->feedback->reviewResultList['clarify'] = 'To Be Clarified';

$lang->feedback->statusList['']           = '';
$lang->feedback->statusList['noreview']   = 'Pending Review';
$lang->feedback->statusList['clarify']    = 'To Be Clarified';
$lang->feedback->statusList['wait']       = 'Waiting';
$lang->feedback->statusList['commenting'] = 'Doing';
$lang->feedback->statusList['replied']    = 'Replied';
$lang->feedback->statusList['asked']      = 'Doubted';
$lang->feedback->statusList['closed']     = 'Closed';

$lang->feedback->closedReasonList['']          = '';
$lang->feedback->closedReasonList['commented'] = 'Replied';
$lang->feedback->closedReasonList['repeat']    = 'Repeat';
$lang->feedback->closedReasonList['refuse']    = 'Reject';

$lang->feedback->solutionList['']            = '';
$lang->feedback->solutionList['tobug']       = 'Convert to Bug';
$lang->feedback->solutionList['tostory']     = 'Convert to ' . $lang->SRCommon;
$lang->feedback->solutionList['touserstory'] = 'Convert to ' . $lang->URCommon;
$lang->feedback->solutionList['totask']      = 'Convert to task';
$lang->feedback->solutionList['totodo']      = 'Convert to Todo';

$lang->feedback->publicList['']  = '';
$lang->feedback->publicList['0'] = 'Private';
$lang->feedback->publicList['1'] = 'Public';

$lang->feedback->confirmDelete = 'Do you want to delete this feedback?';
$lang->feedback->confirmClose  = 'Do you want to close this feedback?';
$lang->feedback->noProject     = 'Haven’t chosen a project yet';
$lang->feedback->noExecution   = 'Haven’t chosen a execution yet';

$lang->feedback->commented        = '$date, replied by <strong>$actor</strong>.' . "\n";
$lang->feedback->noModule         = '<div>You have no categories.</div>';
$lang->feedback->batchEditTip     = 'Feedback with ID %s is not created by the user and will be ignored automatically';
$lang->feedback->mustChooseResult = 'Select Result';

$lang->feedback->mustInputComment['replied']   = 'Reply content must be filled in';
$lang->feedback->mustInputComment['commented'] = 'Comment content must be filled in';
$lang->feedback->mustInputComment['asked']     = 'Ask content must be filled in';

$lang->feedback->action = new stdclass();
$lang->feedback->action->closed   = array('main' => '$date, closed by <strong>$actor</strong>. Close Reason is <strong>$extra</strong>.', 'extra' => 'closedReasonList');
$lang->feedback->action->reviewed = array('main' => '$date, reviewed by <strong>$actor</strong>. The result is <strong>$extra</strong>.', 'extra' => 'reviewResultList');

$lang->feedback->featureBar['admin']['all']        = 'All';
$lang->feedback->featureBar['admin']['wait']       = 'Waiting';
$lang->feedback->featureBar['admin']['doing']      = 'Doing';
$lang->feedback->featureBar['admin']['toclosed']   = 'To Closed';
$lang->feedback->featureBar['admin']['review']     = 'Review';
$lang->feedback->featureBar['admin']['assigntome'] = 'AssignedToMe';
$lang->feedback->featureBar['admin']['openedbyme'] = 'FeedbackByMe';
$lang->feedback->featureBar['admin']['public']     = 'Public';

$lang->feedback->featureBar['admin']['more']['tostory']       = "Have to {$lang->SRCommon}";
$lang->feedback->featureBar['admin']['more']['torequirement'] = "Have to {$lang->URCommon}";
$lang->feedback->featureBar['admin']['more']['totask']        = 'Have to Task';
$lang->feedback->featureBar['admin']['more']['tobug']         = 'Have to Bug';
$lang->feedback->featureBar['admin']['more']['totodo']        = 'Have to Todo';
$lang->feedback->featureBar['admin']['more']['toticket']      = 'Have to Ticket';

$lang->feedback->notifyList['0'] = 'no';
$lang->feedback->notifyList['1'] = 'yes';

$lang->feedback->priList[0] = '';
$lang->feedback->priList[1] = '1';
$lang->feedback->priList[2] = '2';
$lang->feedback->priList[3] = '3';
$lang->feedback->priList[4] = '4';

==> ZenTaoPMS.biz8.0.php7.1.zip: zentaopms/extension/biz/feedback/lang/de.php <==
<?php
global $config;
$lang->feedback->common            = 'Feedback';
$lang->feedback->module            = 'Module';
$lang->feedback->moduleAB          = 'Module';
$lang->feedback->allModule         = 'All Module';
$lang->feedback->manageCate        = 'Manage Module';
$lang->feedback->index             = 'Feedback Home';
$lang->feedback->create            = 'Add Feedback';
$lang->feedback->edit              = 'Edit Feedback';
$lang->feedback->editOthers        = 'Edit Other Feedback';
$lang->feedback->createFaq         = 'Add FAQ';
$lang->feedback->faq               = 'FAQ';
$lang->feedback->nonRDBrowse       = 'Feedback Interface';
$lang->feedback->browse            = 'Feedback List';
$lang->feedback->list              = 'Feedback';
$lang->feedback->header            = 'Feedback';
$lang->feedback->view              = 'Feedback Detail';
$lang->feedback->review            = 'Review';
$lang->feedback->reviewAction      = 'Review Feedback';
$lang->feedback->adminView         = 'Developer Interface';
$lang->feedback->admin             = 'Developer Feedback List';
$lang->feedback->close             = 'Close';
$lang->feedback->closeAction       = 'Close Feedback';
$lang->feedback->feelLike          = ' like it!';
$lang->feedback->ask               = 'Doubt';
$lang->feedback->toStory           = 'To ' . $lang->SRCommon;
$lang->feedback->toUserStory       = 'To ' . $lang->URCommon;
$lang->feedback->toTask            = 'To Task';
$lang->feedback->toBug             = 'To Bug';
$lang->feedback->toTodo            = 'To Todo';
$lang->feedback->toTicket          = 'To Ticket';
$lang->feedback->story             = $lang->SRCommon;
$lang->feedback->userStory         = $lang->URCommon;
$lang->feedback->bug               = 'Bug';
$lang->feedback->todo              = 'Todo';
$lang->feedback->task              = 'Task';
$lang->feedback->ticket            = 'Ticket';
$lang->feedback->reply             = 'Reply';
$lang->feedback->replyAction       = 'Reply Feedback';
$lang->feedback->convert           = 'Convert';
$lang->feedback->assign            = 'AssignTo';
$lang->feedback->assignAction      = 'Assign Feedback';
$lang->feedback->export            = 'Export';
$lang->feedback->exportAction      = 'Export Feedback';
$lang->feedback->assignTo          = 'AssignTo';
$lang->feedback->mailto            = 'Mailto';
$lang->feedback->delete            = 'Delete Feedback';
$lang->feedback->activate          = 'Activate';
$lang->feedback->mailNotify        = 'Email Notification';
$lang->feedback->search            = 'Search';
$lang->feedback->comment           = 'Comment';
$lang->feedback->commentAB         = 'Remark';
$lang->feedback->products          = 'Setting';
$lang->feedback->batchEdit         = 'Batch Edit';
$lang->feedback->batchClose        = 'Batch Close';
$lang->feedback->batchReview       = 'Batch Review';
$lang->feedback->batchAssignTo     = 'Batch Assign';
$lang->feedback->batchChangeModule = 'Batch Change Modules';
$lang->feedback->manageProduct     = 'Manage User Privilege';
$lang->feedback->consumed          = 'Total Cost';
$lang->feedback->noFeedback        = 'No feedback for the time being.';
$lang->feedback->import            = 'Import';
$lang->feedback->exportTemplate    = 'Export Template';
$lang->feedback->exportData        = 'Export Data';
$lang->feedback->pri               = 'Pri';
$lang->feedback->source            = 'Source company';
$lang->feedback->sourceInfo        = 'Feedback source';
$lang->feedback->internalContact   = 'Internal contact';
$lang->feedback->company           = 'Feedback company';
$lang->feedback->email             = 'Feedback email';

$lang->feedback->id             = 'ID';
$lang->feedback->product        = $lang->productCommon;
$lang->feedback->title          = 'Title';
$lang->feedback->storyTitle     = $lang->SRCommon;
$lang->feedback->type           = 'Type';
$lang->feedback->solution       = 'Treatment Plan';
$lang->feedback->desc           = 'Description';
$lang->feedback->status         = 'Status';
$lang->feedback->subStatus      = 'Sub Status';
$lang->feedback->openedBy       = 'CreatedBy';
$lang->feedback->openedDate     = 'CreatedDate';
$lang->feedback->processedBy    = 'RepliedBy';
$lang->feedback->processedDate  = 'Replied';
$lang->feedback->reviewedBy     = 'ReviewedBy';
$lang->feedback->reviewedDate   = 'Reviewed';
$lang->feedback->reviewResult   = 'Reviewed Result';
$lang->feedback->reviewedByAB   = 'Reviewer';
$lang->feedback->reviewedDateAB = 'Date';
$lang->feedback->reviewResultAB = 'Result';
$lang->feedback->assignedTo     = 'AssignedTo';
$lang->feedback->assignedDate   = 'Assigned';
$lang->feedback->activatedBy    = 'activatedBy';
$lang->feedback->activatedDate  = 'activatedDate';
$lang->feedback->closedBy       = 'ClosedBy';
$lang->feedback->closedDate     = 'Closed';
$lang->feedback->closedReason   = 'Close Reason';
$lang->feedback->public         = 'Public';
$lang->feedback->publicAB       = 'Public';
$lang->feedback->notify         = 'Notification';
$lang->feedback->notifyEmail    = 'Notification Email';
$lang->feedback->notifyEmailAB  = 'Feedback Email';
$lang->feedback->feedbackBy     = 'Feedback';
$lang->feedback->likes          = 'Likes';
$lang->feedback->result         = 'Result';
$lang->feedback->files          = 'Files';
$lang->feedback->labelBasic     = 'Basic';
$lang->feedback->dept           = 'Department';
$lang->feedback->editedBy       = 'ModifiedBy';
$lang->feedback->editedDate     = 'Last Modified';
$lang->feedback->contactInfo    = 'Contact';
$lang->feedback->noAssigned     = 'Unassigned';
$lang->feedback->deptManager    = 'Dept Manager';
$lang->feedback->reviewOpinion  = 'Review Opinion';
$lang->feedback->deleted        = 'Deleted';
$lang->feedback->project        = 'Select project';
$lang->feedback->execution      = 'Select ' . $lang->execution->common;

$lang->feedback->lblBasic       = 'Basic Info';
$lang->feedback->lblTrace       = 'Traceability Diagram';
$lang->feedback->assigntome     = 'AssignedToMe';
$lang->feedback->allProduct     = 'All ' . $lang->productCommon;
$lang->feedback->nextStep       = 'Next';
$lang->feedback->selectProjects = 'Select Projects';
$lang->feedback->repeatFeedback = 'Repeat Feedback';

$lang->feedback->grantUser   = 'Authorized User';
$lang->feedback->noGrantUser = 'Unauthorized User';
$lang->feedback->hasPrivUser = 'Feedback users have privileges of all products by default. If any privilege is assigned, they will have the privileges of the related product.';

$lang->feedback->mergeModule    = 'Merge module';
$lang->feedback->mergeTip       = 'There are %d pieces of data to be merged this time, 50 pieces of data to be merged per page, and %d times to be merged.';
$lang->feedback->closedFeedback = 'Feedback %s is closed and will not be closed.';
$lang->feedback->feedbackModule = 'Feedback module';
$lang->feedback->productModule  = 'Product module';
$lang->feedback->syncProduct    = 'Synchronize product modules';
$lang->feedback->syncProductTo  = 'Sync to product';
$lang->feedback->syncConfirm    = 'Whether to merge the existing module with the product module';
$lang->feedback->syncWarning    = 'After the product module is synchronized, it cannot be revoked. Please click Confirm carefully';

$lang->feedback->productSetting          = 'Product Setting';
$lang->feedback->head                    = 'Feedback Manager';
$lang->feedback->ticketHead              = 'Ticket Manager';
$lang->feedback->productSettingSaveError = 'At least one product has to be kept in the Product Setting for the feedback function to work properly.';

$lang->feedback->syncLeveList[1]  = 'One level module';
$lang->feedback->syncLeveList[2]  = 'Two level module';
$lang->feedback->syncLeveList[3]  = 'Three level module';
$lang->feedback->syncLeveList[4]  = 'Four level module';
$lang->feedback->syncLeveList[5]  = 'Five level module';

$lang->feedback->tabList['all']      = 'All';
$lang->feedback->tabList['unclosed'] = 'Unclosed';
$lang->feedback->tabList['public']   = 'Public';

$lang->feedback->typeList[''] = '';
$lang->feedback->typeList['story']       = 'Story';
$lang->feedback->typeList['task']        = 'Task';
$lang->feedback->typeList['bug']         = 'Bug';
$lang->feedback->typeList['todo']        = 'Todo';
$lang->feedback->typeList['advice']      = 'Advice';
$lang->feedback->typeList['issue']       = 'Issue';
$lang->feedback->typeList['risk']        = 'Risk';
$lang->feedback->typeList['opportunity'] = 'Opportunity';

$lang->feedback->reviewResultList['']        = '';
$lang->feedback->reviewResultList['pass']    = 'Pass';
$lang->feedback->reviewResultList['clarify'] = 'To Be Clarified';

$lang->feedback->statusList['']           = '';
$lang->feedback->statusList['noreview']   = 'Pending Review';
$lang->feedback->statusList['clarify']    = 'To Be Clarified';
$lang->feedback->statusList['wait']       = 'Waiting';
$lang->feedback->statusList['commenting'] = 'Doing';
$lang->feedback->statusList['replied']    = 'Replied';
$lang->feedback->statusList['asked']      = 'Doubted';
$lang->feedback->statusList['closed']     = 'Closed';

$lang->feedback->closedReasonList['']          = '';
$lang->feedback->closedReasonList['commented'] = 'Replied';
$lang->feedback->closedReasonList['repeat']    = 'Repeat';
$lang->feedback->closedReasonList['refuse']    = 'Reject';

$lang->feedback->solutionList['']            = '';
$lang->feedback->solutionList['tobug']       = 'Convert to Bug';
$lang->feedback->solutionList['tostory']     = 'Convert to ' . $lang->SRCommon;
$lang->feedback->solutionList['touserstory'] = 'Convert to ' . $lang->URCommon;
$lang->feedback->solutionList['totask']      = 'Convert to task';
$lang->feedback->solutionList['totodo']      = 'Convert to Todo';
$lang->feedback->solutionList['toticket']    = 'Convert to Ticket';

$lang->feedback->publicList['']  = '';
$lang->feedback->publicList['0'] = 'Private';
$lang->feedback->publicList['1'] = 'Public';

$lang->feedback->confirmDelete = 'Do you want to delete this feedback?';
$lang->feedback->confirmClose  = 'Do you want to close this feedback?';
$lang->feedback->noProject     = 'Haven’t chosen a project yet';
$lang->feedback->noExecution   = 'Haven’t chosen a execution yet';

$lang->feedback->commented            = '$date, replied by <strong>$actor</strong>.' . "\n";
$lang->feedback->noModule             = '<div>You have no categories.</div>';
$lang->feedback->batchEditTip         = 'Feedback with ID %s is not created by the user and will be ignored automatically';
$lang->feedback->mustChooseResult     = 'Select Result';
$lang->feedback->ignoreClosedFeedback = "Feedback %s status is closed, and the operation has been filtered.";

$lang->feedback->mustInputComment['replied']   = 'Reply content must be filled in';
$lang->feedback->mustInputComment['commented'] = 'Comment content must be filled in';
$lang->feedback->mustInputComment['asked']     = 'Ask content must be filled in';

$lang->feedback->action = new stdclass();
$lang->feedback->action->closed   = array('main' => '$date, closed by <strong>$actor</strong>. Close Reason is <strong>$extra</strong>.', 'extra' => 'closedReasonList');
$lang->feedback->action->reviewed = array('main' => '$date, reviewed by <strong>$actor</strong>. The result is <strong>$extra</strong>.', 'extra' => 'reviewResultList');

$lang->feedback->featureBar['admin']['all']        = 'All';
$lang->feedback->featureBar['admin']['wait']       = 'Waiting';
$lang->feedback->featureBar['admin']['doing']      = 'Doing';
$lang->feedback->featureBar['admin']['toclosed']   = 'To Closed';
$lang->feedback->featureBar['admin']['review']     = 'Review';
$lang->feedback->featureBar['admin']['assigntome'] = 'AssignedToMe';
$lang->feedback->featureBar['admin']['openedbyme'] = 'FeedbackByMe';
$lang->feedback->featureBar['admin']['public']     = 'Public';

$lang->feedback->featureBar['admin']['more']['tostory']       = "Have to {$lang->SRCommon}";
$lang->feedback->featureBar['admin']['more']['torequirement'] = "Have to {$lang->URCommon}";
$lang->feedback->featureBar['admin']['more']['totask']        = 'Have to Task';
$lang->feedback->featureBar['admin']['more']['tobug']         = 'Have to Bug';
$lang->feedback->featureBar['admin']['more']['totodo']        = 'Have to Todo';
$lang->feedback->featureBar['admin']['more']['toticket']      = 'Have to Ticket';

$lang->feedback->notifyList['']  = '';
$lang->feedback->notifyList['0'] = 'no';
$lang->feedback->notifyList['1'] = 'yes';

$lang->feedback->priList[0] = '';
$lang->feedback->priList[1] = '1';
$lang->feedback->priList[2] = '2';
$lang->feedback->priList[3] = '3';
$lang->feedback->priList[4] = '4';

$lang->feedback->productSettingNoProduct = 'No product can be set at present';
$lang->feedback->accessDenied            = 'You have no access to the feedback.';
